@@ -3,7 +3,7 @@ package Fortran::Format;
 use strict;
 use warnings;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 #use Data::Dumper;
 our $DEBUG = 0;
 use Carp;
@@ -941,6 +941,10 @@ sub write {
 
 =back
 
+=head1 VERSION
+
+0.53
+
 =head1 SEE ALSO
 
 The Fortran format specification: 
